@@ -27,7 +27,8 @@ configs_factory = providers.Singleton(lambda: {})
 subject_storage_factory = providers.Factory(lambda *args, **kwargs: EmptySubjectStorage())
 
 subject_factory = providers.Factory(Subject)
-proc_events_rx_factory = providers.Singleton(subject.ReplaySubject)
+# proc_events_rx_factory = providers.Singleton(subject.ReplaySubject)
+proc_events_rx_factory = subject.ReplaySubject()
 event_router_factory = providers.Singleton(EventRouter)
 event_dispatcher_factory = providers.Singleton(BaseDispatcher)
 exceptions_dumpers_factory = providers.Singleton(ExceptionsDumpers)
